﻿#include "ImageGen.h"
#include <sstream>
#include <iostream>

#include <cmath>

const static double _pi = 3.14159265359;

// Default is for a circle between 80-120MHz on both axes
LissajousImageGen::LissajousImageGen() :
	X_(100.0), Y_(100.0), span(20.0), P_(90.0), Yinc_(1), Xinc_(1)
{

}

std::shared_ptr<Image> LissajousImageGen::Generate(int points)
{
	std::stringstream ss;
	ss << "Lissajous " << Yinc_ << ":" << Xinc_ << " d=" << (P_ / 360.0) << " @X:" << X_ << " Y:" << Y_ << " Span:" << span;
	auto img = std::make_shared<Image>(ss.str());

	double x_accum = 0.0;
	double y_accum = x_accum + (P_ / (360.0 * Xinc_ * Yinc_)) ;
	double phase_inc = (1.0 / points);

	for (int i = 0; i < points; i++)
	{
		FAP x, y;

		x.ampl = y.ampl = Percent(100.0);
		x.phase = y.phase = Degrees(0.0);

		x.freq = X_ + cos(2.0 * _pi * x_accum * Xinc_) * span;
		y.freq = Y_ + cos(2.0 * _pi * y_accum * Yinc_) * span;

		x_accum += phase_inc;
		y_accum += phase_inc;

		ImagePoint pt(x, x, y, y, (x.freq / 250.0), (y.freq / 250.0), 0);
		img->AddPoint(pt);
	}
	return img;
}